@@ -6,7 +6,7 @@ options(digits = 4, width = 90, keep.source = FALSE)
 
 mSource <- function(file, ...)
     source(system.file(file, ..., package = "expm", mustWork=TRUE))
-mSource("test-tools.R")## -> assertError(), rMat(), ..
+mSource("test-tools.R")## -> assertError(), rMat(), .. doExtras
 mSource("demo", "exact-fn.R")
 doExtras
 
@@ -34,6 +34,17 @@ re.m2ex3 <- function(eps, EXPMlist)
     sapply(EXPMlist, function(EXPM) relErr(r$expA, EXPM(r$A)))
 }
 
+## check 1x1 matrices
+stopifnot(
+    ## these had failed before 2017-03-28 (= Liselotte's 58-th birthday):
+    all.equal(as.matrix(sqrtm(matrix(4))),  matrix(2)) ,
+    all.equal(as.matrix(logm (matrix(pi))), matrix(log(pi))) ,
+  ## these had "always" worked :
+    all.equal(as.matrix(expm (matrix(0))), matrix(1)) ,
+    all.equal(as.matrix(expm (matrix(1))), matrix(exp(1)))
+)
+
+
 set.seed(321)
 re <- replicate(1000,
                 c(re.nilA3(rlnorm(3),list(function(x)expm(x,"Pade"))),
@@ -92,8 +103,14 @@ expm.safe.Eigen <- function(x, silent = FALSE) {
     if(inherits(r, "try-error")) NA else r
 }
 
+## the S4 generic
+Matrix::expm
+## the dgeMatrix method:
+expm.Matr.dge <- function(x) getDataPart(getMethod("expm", "dgeMatrix"))(Matrix::..2dge(x))
 expmList <-
-    list(Ward  = function(x) expm::expm(x, "Ward77"),
+    list(Matr = Matrix::expm,
+         Matr.d = expm.Matr.dge,
+         Ward  = function(x) expm::expm(x, "Ward77"),
 	 s.P.s = function(x) expm::expm(x, "Pade"),
 	 s.P.sO= function(x) expm::expm(x, "PadeO"),
 	 s.P.sRBS= function(x) expm::expm(x, "PadeRBS"),
